@@ -372,6 +372,9 @@ def cache_file(path, saltenv='base'):
         salt '*' cp.cache_file salt://foo/bar.conf saltenv=config
         salt '*' cp.cache_file salt://foo/bar.conf?saltenv=config
 
+    If the path being cached is a ``salt://`` URI, and the path does not exist,
+    then ``False`` will be returned.
+
     .. note::
         It may be necessary to quote the URL when using the querystring method,
         depending on the shell being used to run the command.
@@ -688,7 +691,7 @@ def push(path, keep_symlinks=False, upload_path=None, remove_source=False):
     load_path_split_drive = os.path.splitdrive(load_path_normal)[1]
 
     # Finally, split the remaining path into a list for delivery to the master
-    load_path_list = os.path.split(load_path_split_drive)
+    load_path_list = [_f for _f in load_path_split_drive.split(os.sep) if _f]
 
     load = {'cmd': '_file_recv',
             'id': __opts__['id'],
