@@ -293,7 +293,7 @@ def present(name,
 
         .. versionadded:: 2016.3.0
     '''
-    name = ' '.join(name.strip().split())
+    name = name.strip()
     if identifier is False:
         identifier = name
     ret = {'changes': {},
@@ -380,7 +380,7 @@ def absent(name,
     ###       cannot be removed from the function definition, otherwise the use
     ###       of unsupported arguments will result in a traceback.
 
-    name = ' '.join(name.strip().split())
+    name = name.strip()
     if identifier is False:
         identifier = name
     ret = {'name': name,
@@ -509,7 +509,7 @@ def file(name,
         Overrides the default backup mode for the user's crontab.
     '''
     # Initial set up
-    mode = salt.utils.normalize_mode('0600')
+    mode = '0600'
     owner, group, crontab_dir = _get_cron_info()
 
     cron_path = salt.utils.mkstemp()
@@ -564,6 +564,7 @@ def file(name,
             template,
             source,
             source_hash,
+            source_hash_name,
             owner,
             group,
             mode,
@@ -688,7 +689,7 @@ def env_absent(name,
         the root user
     '''
 
-    name = ' '.join(name.strip().split())
+    name = name.strip()
     ret = {'name': name,
            'result': True,
            'changes': {},
